@@ -112,7 +112,7 @@ class Trainer(object):
                     def closure():
                         self.optimizer.zero_grad()
                         output = self.model(images)
-                        current_iter = (self.current_index* self.tr_dl.num_iteration + self.tr_dl.now_iter) /(self.tr_dl.num_iteration*len(self.tr_dl.dataset))
+                        current_iter = (self.tr_dl.current_index* self.tr_dl.num_iteration + self.tr_dl.now_iter) /(self.tr_dl.num_iteration*len(self.tr_dl.dataset))
                         loss = self.calculate_loss(output, seg, writer, e + current_iter)
                         loss.backward()
                         return loss
@@ -121,20 +121,25 @@ class Trainer(object):
                 else:
                     output = self.model(images)
                     self.optimizer.zero_grad()
-                    current_iter = (self.current_index* self.tr_dl.num_iteration + self.tr_dl.now_iter) /(self.tr_dl.num_iteration*len(self.tr_dl.dataset))
+                    current_iter = (self.tr_dl.current_index* self.tr_dl.num_iteration + self.tr_dl.now_iter) /(self.tr_dl.num_iteration*len(self.tr_dl.dataset))
                     loss = self.calculate_loss(output, seg, writer, e + current_iter)
                     loss.backward()
                     self.optimizer.step()
                 
                 if self.tr_dl.current_index < 10 and not isinstance(self.optimizer, SAMSGD):
+                    print("###########", self.tr_dl.current_index, "###########")
                     if not self.is_deep_supervision:
+                        print('output')
                         plt.imshow(torch.argmax(output[0,:,output.shape[2]//2], dim = 0).detach().cpu(), vmax =1 , vmin= 0)
                         plt.show()
-                    elif isinstance(self.optimizer, SAMSGD):
+                    elif not isinstance(self.optimizer, SAMSGD):
+                        print('output')
                         plt.imshow(torch.argmax(output[0,0,:,output.shape[2]//2], dim = 0).detach().cpu(), vmax =1 , vmin= 0)
                         plt.show()
+                    print('images')
                     plt.imshow(images[0,0,output.shape[2]//2].detach().cpu())
                     plt.show()
+                    print('ground_truth')
                     plt.imshow(seg[0,output.shape[2]//2].detach().cpu(), vmax =1 , vmin= 0)
                     plt.show()
 
@@ -149,7 +154,7 @@ class Trainer(object):
                     with torch.no_grad():
                         images, seg = self.val_dl.generate_train_batch()
                         output = self.model(images)
-                        current_iter = (self.current_index* self.tr_dl.num_iteration + self.tr_dl.now_iter) /(self.tr_dl.num_iteration*len(self.tr_dl.dataset))
+                        current_iter = (self.val_dl.current_index* self.val_dl.num_iteration + self.val_dl.now_iter) /(self.val_dl.num_iteration*len(self.val_dl.dataset))
                         loss = self.calculate_loss(output, seg, writer, e + current_iter)
                         if self.visualization != None:
                             if self.val_dl.current_index == 0:
